@@ -354,7 +354,9 @@ def rm_temp_locked_file(p_file_path) -> bool:
             if p_file_path.is_dir():
                 shutil.rmtree(p_file_path)
             success = True
-        except shutil.Error:
+        except shutil.Error as err:
+            crash_retry_cntr += 1
+        except PermissionError as err:
             crash_retry_cntr += 1
         else:
             crash_retry_cntr = CRASH_RETRY
@@ -389,7 +391,7 @@ def rm_tree(p_pth, p_crash = True):
             if src.is_file():
                 try:
                     src.unlink()
-                except OSError:
+                except PermissionError:
                     rm_temp_locked_file(src)
             elif src.is_dir():
                 try:
